Page 113 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 113

Home

    in the churches that dotted the land, many of which had

    schools and hospitals in connection with their work.
    Agriculture flourished and, by 1810, some exports

    were on a par with the United States. Many

    with

    the

    States.

    were

    on

    par

    manufactured goods competed with England in volume.
    Everything about Mexico bore the fruits of a happy and
    industrious people led to this plateau of greatness by the
    love and leadership of the dedicated priests and nuns of
    the Catholic Church.

    The decline of Mexico started when religious
    influence began declining after the king of Spain, Charles
    II, expelled the Jesuits in 1767 and the state seized the
    Jesuits' Pious Fund of some forty-five million dollars.
    This money had been used by the Jesuits to lend to small
    farmers at 5 percent interest, with the interest being used

    for charity. :
    When the Cadiz Constitution of 1820 restricted the

    rights and liberties of the Church, and The Cortes
    rejected Mexico's submitted Guarantees of Religious
    Independence and Union, Royalist leader Iturbide was
    proclaimed Emperor of an Independent Mexico.

    But a peaceful and prosperous Mexico, united by a
    common religious faith, was not allowed to continue.
    The events that followed were replays of the events of
    the French Revolution, and like that revolution, began in
    the Illuminist Lodges. These lodges had been imported
    into Mexico by way of France, Spain, and the United

    States.

    108

    The Secret Side of History

    school texts, and Bibles. Evidence of culture was found